'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

// Copyright (c) Chidera Ike. All rights reserved. Licensed under the MIT license.
/**
 * Defines the area in which selected/highlighted text will render a popover.
 * @public ❤️ from Nigeria
 */

var HighlightableTextArea = function HighlightableTextArea(_ref) {
  var popoverItem = _ref.popoverItem,
      onHighlightText = _ref.onHighlightText,
      _ref$xOffset = _ref.xOffset,
      xOffset = _ref$xOffset === void 0 ? 0 : _ref$xOffset,
      _ref$yOffset = _ref.yOffset,
      yOffset = _ref$yOffset === void 0 ? 10 : _ref$yOffset,
      _ref$zIndex = _ref.zIndex,
      zIndex = _ref$zIndex === void 0 ? 10 : _ref$zIndex,
      children = _ref.children;

  var _React$useState = React.useState(0),
      x = _React$useState[0],
      setX = _React$useState[1];

  var _React$useState2 = React.useState(0),
      y = _React$useState2[0],
      setY = _React$useState2[1];

  var _React$useState3 = React.useState(''),
      text = _React$useState3[0],
      setText = _React$useState3[1];

  var _React$useState4 = React.useState(false),
      showPopover = _React$useState4[0],
      setShowPopover = _React$useState4[1];

  var highlightRef = React.createRef();
  React.useEffect(function () {
    window.addEventListener('mouseup', highlightAreaEvent);
    return function () {
      window.removeEventListener('mouseup', highlightAreaEvent);
    };
  });

  var hidePopover = function hidePopover() {
    setShowPopover(false);
  };

  var highlightAreaEvent = function highlightAreaEvent(event) {
    var selection = window.getSelection();
    var selectedText = selection == null ? void 0 : selection.toString().trim();

    if (!selectedText) {
      hidePopover();
      return;
    }

    var selectionRange = selection == null ? void 0 : selection.getRangeAt(0);
    var startNode = (selectionRange == null ? void 0 : selectionRange.startContainer.parentNode) || null;
    var endNode = (selectionRange == null ? void 0 : selectionRange.endContainer.parentNode) || null;
    var highlightable = highlightRef.current;
    var highlightableRegion = highlightable == null ? void 0 : highlightable.querySelector("#rhp");

    if (highlightableRegion) {
      if (!highlightableRegion.contains(startNode) || !highlightableRegion.contains(endNode)) {
        hidePopover();
        return;
      }
    } else if (!(highlightable != null && highlightable.contains(startNode)) || !(highlightable != null && highlightable.contains(endNode))) {
      hidePopover();
      return;
    }

    if (!(startNode != null && startNode.isSameNode(endNode))) {
      hidePopover();
      return;
    }

    var _selectionRange$getBo = selectionRange.getBoundingClientRect(),
        x = _selectionRange$getBo.x,
        y = _selectionRange$getBo.y,
        width = _selectionRange$getBo.width;

    if (!width) {
      hidePopover();
      return;
    }

    setX(x + width / 2);
    setY(y + window.scrollY - yOffset);
    setText(selectedText);
    setShowPopover(true);
    onHighlightText && onHighlightText(event);
  };

  return React.createElement("div", {
    ref: highlightRef,
    id: 'rhp'
  }, showPopover && React.createElement("div", {
    className: 'popover-container',
    style: {
      left: x + xOffset + "px",
      top: y + "px",
      zIndex: zIndex
    },
    role: "presentation",
    onMouseDown: function onMouseDown(e) {
      return e.preventDefault();
    }
  }, popoverItem ? popoverItem(text, setShowPopover) : React.createElement("div", {
    className: "popover-item"
  }, React.createElement("span", {
    role: "button"
  }, "React Highlight Popover"))), children);
};

exports.HighlightableTextArea = HighlightableTextArea;
//# sourceMappingURL=react-highlight-popover.cjs.development.js.map
