import { useState, createRef, useEffect, createElement } from 'react';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ":root{--shadow-color:0deg 0% 54%;--shadow-elevation:0.3px 0.5px 0.7px hsl(var(--shadow-color)/0.36),0.8px 1.6px 2px -0.8px hsl(var(--shadow-color)/0.36),2.1px 4.1px 5.2px -1.7px hsl(var(--shadow-color)/0.36),5px 10px 12.6px -2.5px hsl(var(--shadow-color)/0.36)}.popover-container{position:absolute;transform:translate(-50%,-100%);transition:top .3s,left .3s}.popover-item{align-items:center;background:#ddd;border-radius:3px;box-shadow:var(--shadow-elevation);display:flex;padding:6px 10px}.popover-item:after{border-left:6px solid transparent;border-right:6px solid transparent;border-top:6px solid #ddd;bottom:-5px;content:\"\";height:0;left:50%;position:absolute;transform:translateX(-50%);width:0}";
styleInject(css_248z);

// Copyright (c) Chidera Ike. All rights reserved. Licensed under the MIT license.
/**
 * Defines the area in which selected/highlighted text will render a popover.
 * @public ❤️ from Nigeria
 */

var HighlightableTextArea = function HighlightableTextArea(_ref) {
  var popoverItem = _ref.popoverItem,
      onHighlightText = _ref.onHighlightText,
      _ref$xOffset = _ref.xOffset,
      xOffset = _ref$xOffset === void 0 ? 0 : _ref$xOffset,
      _ref$yOffset = _ref.yOffset,
      yOffset = _ref$yOffset === void 0 ? 10 : _ref$yOffset,
      _ref$zIndex = _ref.zIndex,
      zIndex = _ref$zIndex === void 0 ? 10 : _ref$zIndex,
      children = _ref.children;

  var _React$useState = useState(0),
      x = _React$useState[0],
      setX = _React$useState[1];

  var _React$useState2 = useState(0),
      y = _React$useState2[0],
      setY = _React$useState2[1];

  var _React$useState3 = useState(''),
      text = _React$useState3[0],
      setText = _React$useState3[1];

  var _React$useState4 = useState(false),
      showPopover = _React$useState4[0],
      setShowPopover = _React$useState4[1];

  var highlightRef = createRef();
  useEffect(function () {
    window.addEventListener('mouseup', highlightAreaEvent);
    return function () {
      window.removeEventListener('mouseup', highlightAreaEvent);
    };
  });

  var hidePopover = function hidePopover() {
    setShowPopover(false);
  };

  var highlightAreaEvent = function highlightAreaEvent(event) {
    var selection = window.getSelection();
    var selectedText = selection == null ? void 0 : selection.toString().trim();

    if (!selectedText) {
      hidePopover();
      return;
    }

    var selectionRange = selection == null ? void 0 : selection.getRangeAt(0);
    var startNode = (selectionRange == null ? void 0 : selectionRange.startContainer.parentNode) || null;
    var endNode = (selectionRange == null ? void 0 : selectionRange.endContainer.parentNode) || null;
    var highlightable = highlightRef.current;
    var highlightableRegion = highlightable == null ? void 0 : highlightable.querySelector("#rhp");

    if (highlightableRegion) {
      if (!highlightableRegion.contains(startNode) || !highlightableRegion.contains(endNode)) {
        hidePopover();
        return;
      }
    } else if (!(highlightable != null && highlightable.contains(startNode)) || !(highlightable != null && highlightable.contains(endNode))) {
      hidePopover();
      return;
    }

    if (!(startNode != null && startNode.isSameNode(endNode))) {
      hidePopover();
      return;
    }

    var _selectionRange$getBo = selectionRange.getBoundingClientRect(),
        x = _selectionRange$getBo.x,
        y = _selectionRange$getBo.y,
        width = _selectionRange$getBo.width;

    if (!width) {
      hidePopover();
      return;
    }

    setX(x + width / 2);
    setY(y + window.scrollY - yOffset);
    setText(selectedText);
    setShowPopover(true);
    onHighlightText && onHighlightText(event);
  };

  return createElement("div", {
    ref: highlightRef,
    id: 'rhp'
  }, showPopover && createElement("div", {
    className: 'popover-container',
    style: {
      left: x + xOffset + "px",
      top: y + "px",
      zIndex: zIndex
    },
    role: "presentation",
    onMouseDown: function onMouseDown(e) {
      return e.preventDefault();
    }
  }, popoverItem ? popoverItem(text, setShowPopover) : createElement("div", {
    className: "popover-item"
  }, createElement("span", {
    role: "button"
  }, "React Highlight Popover"))), children);
};

export { HighlightableTextArea };
//# sourceMappingURL=react-highlight-popover.esm.js.map
